@@ -1,5 +1,5 @@
 import unittest
-import chksum
+from src.chksum_cli import chksum
 
 
 class TestCompareHashes(unittest.TestCase):
